@@ -42,4 +42,4 @@ trainer = Trainer(model, F.cross_entropy, opt, epochs=2)            # 训练器
 # trainer = Trainer(model, F.cross_entropy, opt,
 #                   gpus=1 if torch.cuda.is_available() else None)  # 使用GPU
 trainer.fit(train_dl, val_dl)                                       # 训练、验证
-trainer.test(test_dl)                                               # 测试
+trainer.test(test_dl, verbose='False')                                               # 测试
