@@ -43,9 +43,9 @@ scheduler = torch.optim.lr_scheduler.StepLR(opt, 8, gamma=0.1, last_epoch=-1)
 
 
 # 4. --- 训练
-acc = 'acc', Accuracy()
-acc1 = 'acc1', Accuracy(average='macro', num_classes=10)
-f1 = 'f1', F1Score(average='macro', num_classes=10)
+acc = 'acc', Accuracy(task='multiclass', num_classes=10)
+acc1 = 'acc1', Accuracy(task='multiclass', average='macro', num_classes=10)
+f1 = 'f1', F1Score(task='multiclass', average='macro', num_classes=10)
 
 # 每个epoch保存一次模型的callback
 chkpoint_cbk = ModelCheckpoint(monitor='val_loss', dirpath='./checkpoints/',
